@@ -19,4 +19,16 @@ class uwDeclare():
         """ 警告 """
         
         critical = 2
-        """ 致命的エラー """
\ No newline at end of file
+        """ 致命的エラー """
+        
+    class resultRegister(Enum):
+        
+        """
+        登録処理結果
+        """
+        
+        success = 0
+        """ 成功 """
+        
+        failure = 1
+        """ 失敗 """
