@@ -14,7 +14,7 @@ def loggerDecorator(outputString, args_print = []):
         関数の開始～終了でコンソールに文字列を出力するデコレーター
         """
 
-        def  wrapper(*args, **kwargs):
+        def wrapper(*args, **kwargs):
 
             """
             デコレーターのラッパー
@@ -52,10 +52,11 @@ def loggerDecorator(outputString, args_print = []):
                             'e自身:' + str(e)
 
                 # エラーメッセージの出力
-                print(errorInfo)
                 logging.error(errorInfo)
 
-                return
+                # 例外スロー
+                raise Exception
+            
             return ret
 
         return wrapper
