@@ -446,6 +446,14 @@ class recset(Generic[T]):
         # 行状態をdeletedに変更
         self.State = self.rowState.deleted
 
+    def first(self):
+        
+        """
+        カレント行を先頭にする
+        """
+        
+        self.__currentRowIndex = -1
+    
     def eof(self):
         
         """
